ExecutionStatus class sealed

Represents the lifecycle status of a workflow execution.

Uses sealed class for exhaustive pattern matching in switch expressions.

Implementers

Constructors

ExecutionStatus.fromString(String value)
Creates an ExecutionStatus from its database string representation.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The database string representation of this status.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override