RetryPolicyFixed class

Fixed-interval retry strategy.

Inheritance

Constructors

RetryPolicyFixed({required int maxAttempts, required Duration delay})
Creates a RetryPolicyFixed.
const

Properties

delay Duration
Fixed delay between retries.
final
hashCode int
The hash code for this object.
no setteroverride
maxAttempts int
Maximum number of attempts (including the first).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this retry policy to a JSON map.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override