deleteExecution method

  1. @override
Future<void> deleteExecution(
  1. String workflowExecutionId
)
override

Deletes a workflow execution and all associated data (checkpoints, timers, signals).

Use this to clean up completed or failed executions.

Implementation

@override
Future<void> deleteExecution(String workflowExecutionId) async {
  _executions.remove(workflowExecutionId);
  _checkpoints.remove(workflowExecutionId);
  _timers.removeWhere((t) => t.workflowExecutionId == workflowExecutionId);
  _signals.removeWhere((s) => s.workflowExecutionId == workflowExecutionId);
}