loadExecutionsByStatus method
Loads all workflow executions matching any of the given statuses.
Used by RecoveryScanner to find executions that need to be resumed.
Implementation
@override
Future<List<WorkflowExecution>> loadExecutionsByStatus(
List<ExecutionStatus> statuses,
) async {
return _executions.values
.where((e) => statuses.any((s) => s == e.status))
.toList();
}