loadPendingTimers method
Loads all pending timers that should have fired by now or will fire in the near future.
Implementation
@override
Future<List<WorkflowTimer>> loadPendingTimers() async {
return _timers.where((t) => t.status == TimerStatus.pending).toList();
}